Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(276)

Unified Diff: ui/aura/mus/window_manager_delegate.h

Issue 2515233004: Make OnWmDisplayRemoved() take a WindowTreeHost (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ui/aura/mus/window_tree_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/aura/mus/window_manager_delegate.h
diff --git a/ui/aura/mus/window_manager_delegate.h b/ui/aura/mus/window_manager_delegate.h
index b8adfc85e8a876fc54de3f6fe7b5cb596ce2cb81..fe8203e83630f9d32f9031ae5bd9d7456c7d6df5 100644
--- a/ui/aura/mus/window_manager_delegate.h
+++ b/ui/aura/mus/window_manager_delegate.h
@@ -113,8 +113,9 @@ class AURA_EXPORT WindowManagerDelegate {
std::unique_ptr<WindowTreeHostMus> window_tree_host,
const display::Display& display) = 0;
- // Called when a display is removed. |window| is the root of the display.
- virtual void OnWmDisplayRemoved(Window* window) = 0;
+ // Called when a display is removed. |window_tree_host| is the WindowTreeHost
+ // for the display.
+ virtual void OnWmDisplayRemoved(WindowTreeHostMus* window_tree_host) = 0;
// Called when a display is modified.
virtual void OnWmDisplayModified(const display::Display& display) = 0;
« no previous file with comments | « no previous file | ui/aura/mus/window_tree_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698